;; Generated package description from denote.el  -*- no-byte-compile: t -*-
(define-package "denote" "2.3.4" "Simple notes with an efficient file-naming scheme" '((emacs "28.1")) :commit "514a5d0d394adeaa7bc26e90f76376bf149163c8" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote")
